==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/automation/kotlin/inputs/PrivateEndpointPropertyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin.inputs

import com.pulumi.azurenative.automation.inputs.PrivateEndpointPropertyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Private endpoint which the connection belongs to.
 * @property id Resource id of the private endpoint.
 */
public data class PrivateEndpointPropertyArgs(
    public val id: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.automation.inputs.PrivateEndpointPropertyArgs> {
    override fun toJava(): com.pulumi.azurenative.automation.inputs.PrivateEndpointPropertyArgs =
        com.pulumi.azurenative.automation.inputs.PrivateEndpointPropertyArgs.builder()
            .id(id?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PrivateEndpointPropertyArgs].
 */
@PulumiTagMarker
public class PrivateEndpointPropertyArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    /**
     * @param value Resource id of the private endpoint.
     */
    @JvmName("tuaktxfmnrevvkps")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Resource id of the private endpoint.
     */
    @JvmName("mnyouwhhenwejecw")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    internal fun build(): PrivateEndpointPropertyArgs = PrivateEndpointPropertyArgs(
        id = id,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/automation/kotlin/inputs/PrivateEndpointPropertyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin.inputs

import com.pulumi.azurenative.automation.inputs.PrivateEndpointPropertyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Private endpoint which the connection belongs to.
 * @property id Resource id of the private endpoint.
 */
public data class PrivateEndpointPropertyArgs(
    public val id: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.automation.inputs.PrivateEndpointPropertyArgs> {
    override fun toJava(): com.pulumi.azurenative.automation.inputs.PrivateEndpointPropertyArgs =
        com.pulumi.azurenative.automation.inputs.PrivateEndpointPropertyArgs.builder()
            .id(id?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PrivateEndpointPropertyArgs].
 */
@PulumiTagMarker
public class PrivateEndpointPropertyArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    /**
     * @param value Resource id of the private endpoint.
     */
    @JvmName("gmmcvubeetpyvyyu")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Resource id of the private endpoint.
     */
    @JvmName("cgfxnphrrprwsgsm")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    internal fun build(): PrivateEndpointPropertyArgs = PrivateEndpointPropertyArgs(
        id = id,
    )
}
